Returns a character vector of file extensions (without dots) supported by the read block. Useful for sibling packages that need to filter or validate file paths before passing them to blockr.io.
Returns a character vector of file extensions (without dots) supported by the read block. Useful for sibling packages that need to filter or validate file paths before passing them to blockr.io.